@@ -11,11 +11,12 @@ test_that("REMLRT_asreml42", {
   ## use asremlPlus to analyse the wheat (barley) example from section 8.6 of the asreml manual (Butler et al. 2010)
   data(Wheat.dat)
   
+  asreml::asreml.options(extra = 5, ai.sing = TRUE, fail = "soft")
   # Fit initial model
   m1.asr <- asreml(yield ~ Rep + WithinColPairs + Variety, 
                    random = ~ Row + Column + units,
                    residual = ~ ar1(Row):ar1(Column), 
-                   data=Wheat.dat)
+                   maxit = 30, data=Wheat.dat)
   summary(m1.asr)$varcomp
   info <- infoCriteria(m1.asr)
   testthat::expect_equal(info$varDF, 5)
@@ -25,7 +26,7 @@ test_that("REMLRT_asreml42", {
   m2.asr <- asreml(yield ~ Rep + WithinColPairs + Variety, 
                    random = ~ Row + Column,
                    residual = ~ ar1(Row):ar1(Column), 
-                   data=Wheat.dat)
+                   maxit = 30, data=Wheat.dat)
   summary(m2.asr)$varcomp
   info <- infoCriteria(m2.asr)
   testthat::expect_equal(info$varDF, 4)
@@ -44,7 +45,7 @@ test_that("REMLRT_asreml42", {
   m3.asr <- asreml(yield ~ Rep + WithinColPairs + Variety, 
                    random = ~ Row + Column,
                    residual = ~ Row:Column, 
-                   data=Wheat.dat)
+                   maxit = 30, data=Wheat.dat)
   summary(m3.asr)$varcomp
   test3 <- REMLRT(m3.asr, m1.asr)
   testthat::expect_lt(abs(test3$p - 2.596812e-13), 1e-03)
@@ -70,23 +71,24 @@ test_that("Wheat_asreml42", {
   ## Fit several models to the wheat data and caclulate their ICs
   data(Wheat.dat)
   
+  asreml::asreml.options(extra = 5, ai.sing = TRUE, fail = "soft")
   # Fit initial model
   m.max <- asreml(yield ~ Rep + WithinColPairs + Variety, 
                   random = ~ Row + Column + units,
                   residual = ~ ar1(Row):ar1(Column), 
-                  data=Wheat.dat)
+                  maxit = 30, data=Wheat.dat)
 
   #Drop term for within Column pairs
   m1 <- asreml(yield ~ Rep + Variety, 
                random = ~ Row + Column + units,
                residual = ~ ar1(Row):ar1(Column), 
-               data=Wheat.dat)
+               maxit = 30, data=Wheat.dat)
   
   #Drop nugget term
   m2 <- asreml(yield ~ Rep + WithinColPairs + Variety, 
                random = ~ Row + Column,
                residual = ~ ar1(Row):ar1(Column), 
-               data=Wheat.dat)
+               maxit = 30, data=Wheat.dat)
 
   #Drop Row autocorrelation
   m3 <- asreml(yield ~ Rep + WithinColPairs + Variety, 
@@ -98,7 +100,7 @@ test_that("Wheat_asreml42", {
   m4 <- asreml(yield ~ Rep + WithinColPairs + Variety, 
                random = ~ Row + Column + units,
                residual = ~ ar1(Row):Column, 
-               data=Wheat.dat)
+               maxit = 30, data=Wheat.dat)
 
   mods.asr <- list(m.max, m1, m2, m3, m4)
   ic <- infoCriteria(mods.asr, IClikelihood = "full")
